/*******************************************************************************
 * Copyright (C) 2005 - 2014 TIBCO Software Inc. All rights reserved.
 * http://www.jaspersoft.com.
 * 
 * Unless you have purchased  a commercial license agreement from Jaspersoft,
 * the following license terms  apply:
 * 
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 ******************************************************************************/
package com.jaspersoft.webservice.data;

import java.util.HashMap;

import com.jaspersoft.webservice.data.enumerations.LanguageType;

import net.sf.jasperreports.data.DataAdapter;

/**
 * Interface of the WebServiceData adapter
 * 
 * @author Orlandin Marco
 *
 */
public interface WebServiceDataAdapter extends DataAdapter {
	
	/**
	 * Return the URI of the server
	 * 
	 * @return a not null URI for the server
	 */
	public String getWsUri();
	
	/**
	 * Return a not null string with the authorization type
	 * name provided to the server
	 * 
	 * @return the authentication type required from the server
	 * typically none or basic, but can be extended
	 */
	public String getAuthType();
	
	/**
	 * A not null string that specify who will be used
	 * to sent to the server, trough post or get
	 * 
	 * @return a post or get enum
	 */
	public String getVerb();
	
	/**
	 * Return the language of the server response
	 * 
	 * @return the language of the response, typically json
	 * or xml, but can be extended
	 */
	public LanguageType getLanguage();
	
	/**
	 * Return the authentication parameters. They are used
	 * by an authenticator provided by the authentication type
	 * to insert the authentication informations inside the request
	 * 
	 * @return a not null map of parameters used by the authentication. How
	 * they are used depend by the authenticator provided by the authentication
	 * type
	 */
	public HashMap<String, String> getAuthParameters();
	
	/**
	 * Return the value of a specific authentication parameter
	 * 
	 * @param key the name of the parameter
	 * @return the value of the parameter, can be null
	 */
	public String getAuthParameter(String key);
	
	/**
	 * Set the URI of the server
	 * 
	 * @param wsUri a not null URI for the server
	 */
	public void setWsUri(String wsUri);
	
	/**
	 * Set the authentication type, should be not null
	 * 
	 * @param authType a not null authentication type 
	 */
	public void setAuthType(String authType);
	
	/**
	 * Set a value that specify how the request
	 * is sent to the server, trough post or get
	 * 
	 * @param verb the verb
	 */
	public void setVerb(String verb);
	
	/**
	 * Set the language of the server response
	 * 
	 * @return the language of the response, typically json
	 * or xml, but can be extended
	 */
	public void setLanguage(LanguageType language);
	
	/**
	 * Set the authentication parameters. They are used
	 * by an authenticator provided by the authentication type
	 * to insert the authentication informations inside the request
	 * 
	 * @param parameters a map of parameters used by the authentication. How
	 * they are used depend by the authenticator provided by the authentication
	 * type. Must be not null
	 */
	public void setAuthParameters(HashMap<String, String> parameters);
	
	/**
	 * Set the value of a specific authentication parameter
	 * 
	 * @param key the name of the parameter
	 * @param value the value of the parameter, can be null
	 */
	public void setAuthParameter(String key, String value);
}
