/*******************************************************************************
 * Copyright (C) 2005 - 2014 TIBCO Software Inc. All rights reserved.
 * http://www.jaspersoft.com.
 * 
 * Unless you have purchased  a commercial license agreement from Jaspersoft,
 * the following license terms  apply:
 * 
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 ******************************************************************************/
package com.jaspersoft.webservice.data;

import java.util.Map;

import com.jaspersoft.webservice.data.enumerations.AuthType;

import net.sf.jasperreports.data.AbstractDataAdapterService;
import net.sf.jasperreports.engine.JRException;
import net.sf.jasperreports.engine.JasperReportsContext;
import net.sf.jasperreports.engine.ParameterContributorContext;

/**
 * The service used to provide the adapter configuration to the query executer
 * 
 * @author Orlandin Marco
 *
 */
public class WebServiceDataAdapterService extends AbstractDataAdapterService {

	/**
	 * Key used to store in the parameters map the URI of the web service, the object stored is of type String
	 */
	public static final String URI_KEY = "uriKey";
	
	/**
	 * Key used to store in the parameters map authentication type, the object stored is of type AuthType
	 */
	public static final String AUTH_TYPE_KEY = "authTypeKey";
	
	/**
	 * Key used to store in the parameters map the authentication parameters, the object stored is of type Map<String,String>
	 */
	public static final String AUTH_PARAMETERS_KEY = "authParametersKey";
	
	/**
	 * Key used to store in the parameters map the language type, the object stored is of type LanguageType
	 */
	public static final String LANGUAGE_KEY = "languageKey";
	
	/**
	 * Key used to store in the parameters map the verb type, the object stored is of type VerbType
	 */
	public static final String VERB_KEY = "verbKey";
	
	public WebServiceDataAdapterService(ParameterContributorContext paramContribContext, WebServiceDataAdapter dataAdapter) 
	{
		super(paramContribContext, dataAdapter);
	}
	
	public WebServiceDataAdapterService(JasperReportsContext jasperReportsContext, WebServiceDataAdapter dataAdapter)
	{
		super(jasperReportsContext, dataAdapter);
		jasperReportsContext.getExtensions(AuthType.class);
	}
	
	@Override
	public void contributeParameters(Map<String, Object> parameters)throws JRException {
		WebServiceDataAdapter adapter = (WebServiceDataAdapter)getDataAdapter();
		parameters.put(URI_KEY, adapter.getWsUri());
		parameters.put(AUTH_TYPE_KEY, adapter.getAuthType());
		parameters.put(AUTH_PARAMETERS_KEY, adapter.getAuthParameters());
		parameters.put(LANGUAGE_KEY, adapter.getLanguage());
		parameters.put(VERB_KEY, adapter.getVerb());
	}

}
