/*******************************************************************************
 * Copyright (C) 2005 - 2014 TIBCO Software Inc. All rights reserved.
 * http://www.jaspersoft.com.
 * 
 * Unless you have purchased  a commercial license agreement from Jaspersoft,
 * the following license terms  apply:
 * 
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 ******************************************************************************/
package com.jaspersoft.webservice.data;

import net.sf.jasperreports.data.DataAdapter;
import net.sf.jasperreports.data.DataAdapterContributorFactory;
import net.sf.jasperreports.data.DataAdapterService;
import net.sf.jasperreports.engine.ParameterContributorContext;

/**
 * Data adapter service factory to provide the webservice data adapter service when requested
 * 
 * @author Orlandin Marco
 *
 */
public class WebServiceDataAdapterServiceFactory implements DataAdapterContributorFactory {

	/**
	 * This class is a singleton so it store its own instance
	 */
	private static WebServiceDataAdapterServiceFactory instance = null;

	/**
	 * Return a shared instance of the service factory
	 * 
	 * @return a not null instance of this class
	 */
	public static WebServiceDataAdapterServiceFactory getInstance() {
		if (instance == null){
			instance = new WebServiceDataAdapterServiceFactory();
		}
		return instance;
	}

	/**
	 * If the data adapter is of type WebServiceDataAdapter return its service
	 * to contribute the parameters
	 */
	@Override
	public DataAdapterService getDataAdapterService(ParameterContributorContext arg0, DataAdapter dataAdapter) {
		DataAdapterService dataAdapterService = null;
		if (dataAdapter instanceof WebServiceDataAdapter){
			dataAdapterService = new WebServiceDataAdapterService(arg0, (WebServiceDataAdapter) dataAdapter);
		}
		return dataAdapterService;
	}

}
