/*******************************************************************************
 * Copyright (C) 2005 - 2014 TIBCO Software Inc. All rights reserved.
 * http://www.jaspersoft.com.
 * 
 * Unless you have purchased  a commercial license agreement from Jaspersoft,
 * the following license terms  apply:
 * 
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 ******************************************************************************/
package com.jaspersoft.webservice.data.authenitcator;

import java.util.List;
import java.util.Map;

import org.apache.http.client.fluent.Request;

/**
 * An authenticator. It is associated to an authentication type and provide
 * a method that know how to put the authentication parameters inside the
 * server request
 * 
 * @author Orlandin Marco
 *
 */
public interface AuthenticatorInterface {
	
	/**
	 * Write inside the request the authentication informations provided
	 * by the authentication parameters inside its body
	 * 
	 * @param request the http request
	 * @param parameters a not null map of parameters. The implementation must know
	 * which parameter it need and with which key they are stored
	 */
	public void setAuthenication(Request request, Map<String, String> parameters);
	
	/**
	 * Sometimes the authentication is provided trough the URL (get request), this
	 * method is called before the request is created and can connected the url
	 * the parameters if necessary. The result must be a valid url
	 * 
	 * @param url the base URL
	 * @param parameters a not null map of parameters. The implementation must know
	 * which parameter it need and with which key they are stored
	 * @return a not null and valid result URL
	 */
	public String contributeURL(String url, Map<String, String> parameters);
	
	/**
	 * Get a list of the name of the parameters required by this 
	 * authenticator
	 * 
	 * @return a not null list of parameter names
	 */
	public List<String> getRequiredParameters();
	
	/**
	 * Get the localized name of a parameter 
	 * 
	 * @param parameterName the parameter unique name
	 * @return a not null string that is the name of the parameter, eventually
	 * localized, that can be used inside the UI
	 */
	public String getLocalizedParameterName(String parameterName);
	
	/**
	 * Return the java type of a parameter 
	 * 
	 * @param parameterName the name of the parameter
	 * @return the type of the parameter with the specific name
	 */
	public Class<?> getParameterType(String parameterName);
}
