/*******************************************************************************
 * Copyright (C) 2005 - 2014 TIBCO Software Inc. All rights reserved.
 * http://www.jaspersoft.com.
 * 
 * Unless you have purchased  a commercial license agreement from Jaspersoft,
 * the following license terms  apply:
 * 
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 ******************************************************************************/
package com.jaspersoft.webservice.data.authenitcator;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import org.apache.commons.codec.binary.Base64;
import org.apache.http.client.fluent.Request;

/**
 * Basic authenticator that search in the map the username and password parameters and
 * set it to the request
 * 
 * @author Orlandin Marco
 *
 */
public class BasicAuthenticator implements AuthenticatorInterface {
	
	/**
	 * Key for the username
	 */
	public static final String USERNAME_KEY = "username";
	
	/**
	 * Key for the password
	 */
	public static final String PASSWORD_KEY = "password";
	
	private static final List<String> parameters = new ArrayList<String>();
	
	static{
		parameters.add(USERNAME_KEY);
		parameters.add(PASSWORD_KEY);
	}

	@Override
	public void setAuthenication(Request request, Map<String, String> parameters) {
		String username = parameters.get(USERNAME_KEY);
		String password = parameters.get(PASSWORD_KEY);
		if (username == null) username = "";
		if (password == null) password = "";
		String basic_auth = new String(Base64.encodeBase64((username + ":" + password).getBytes()));
		request.addHeader("Authorization", "Basic " + basic_auth);
	}

	/**
	 * The auth informations are written inside the request, so this doesn't do anything
	 */
	@Override
	public String contributeURL(String url, Map<String, String> parameters) {
		return url;
	}

	@Override
	public List<String> getRequiredParameters() {
		return parameters;
	}

	@Override
	public String getLocalizedParameterName(String parameterName) {
		return parameterName;
	}

	@Override
	public Class<?> getParameterType(String parameterName) {
		return String.class;
	}

}
