/*******************************************************************************
 * Copyright (C) 2005 - 2014 TIBCO Software Inc. All rights reserved.
 * http://www.jaspersoft.com.
 * 
 * Unless you have purchased  a commercial license agreement from Jaspersoft,
 * the following license terms  apply:
 * 
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 ******************************************************************************/
package com.jaspersoft.webservice.data.enumerations;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

/**
 * Class used to provide the language types. It work in a similar way to an enum
 * but it is a class to be easily serialized and extensible in the future trough the JR
 * extensions. The object of this class can't be build directly, the class must be extended.
 * 
 * @author Orlandin Marco
 *
 */
public class LanguageType {
	
	/**
	 * The map where all the types instantiated (also if it is a subclass) are stored 
	 */
    protected static final Map<String, LanguageType> KINDS = new HashMap<String, LanguageType>();

    /**
     * Value to represent the JSON language
     */
    public static final LanguageType JSON = new LanguageType("json");
    
    /**
     * Value to represent the XML language
     */
    public static final LanguageType XML = new LanguageType("xml");
    
    /**
     * Value to represent the JSONQL language
     */    
    public static final LanguageType JSONQL = new LanguageType("jsonql");

    /**
     * The value of the current type
     */
    protected final String value;

    /**
     * Create a new type
     * 
     * @param value The value of the current type, should be unique, but this is not check to avoid to 
     * overwrite other types
     */
    protected LanguageType(final String value) {
    	this.value = value;
        KINDS.put(value, this);
    }

    /**
     * Get a language type from its textual value
     * 
     * @param kind the textual representation of the type
     * @return the LanguageType associated or null if the name doesn't correspond to
     * any language 
     */
    public static LanguageType valueOf(final String kind) {
	    return KINDS.get(kind);
    }
    
    /**
     * Return all the defined language types
     * 
     * @return a not null list of the textual representation of the language types
     */
    public static Collection<LanguageType> values(){
    	return KINDS.values();
    }

    /**
     * Return the current type as a string 
     */
    @Override
    public String toString() { 
    	return value; 
    }
}
  