/*******************************************************************************
 * Copyright (C) 2005 - 2014 TIBCO Software Inc. All rights reserved.
 * http://www.jaspersoft.com.
 * 
 * Unless you have purchased  a commercial license agreement from Jaspersoft,
 * the following license terms  apply:
 * 
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 ******************************************************************************/
package com.jaspersoft.webservice.data.query;

import java.util.Map;

import net.sf.jasperreports.engine.JRDataSource;

/**
 * This interface extends the standard datasource to define the methods that
 * a web service datasource must implement. This methods allow to create a copy
 * of the datasource with the response of the server already inside them and with
 * the response not consumed. This allow to pass the response of the server to
 * subreport without send a new request 
 * 
 * @author Orlandin Marco
 *
 */
public interface IWSDataSource extends JRDataSource{

	/**
	 * Clone the current datasource, using the same response of the server from the original one
	 * and also using the same fields map and base path
	 * 
	 * @return a not null datasource, should be a clone of the data source where the method is called
	 * and it should be not consumed.
	 */
	public IWSDataSource clone();
	
	/**
	 * Clone the current datasource, using the same response of the server from the original one
	 * but a different base path and fields expressions map
	 * 
	 * @param basePath the new base path, must be not null and not empty
	 * @param fieldExpressionMap the new expression map, must be not null
	 * @return a not null datasource, should be a clone of the data source where the method is called
	 * and it should be not consumed.
	 */
	public IWSDataSource clone(String basePath, Map<String, String> fieldExpressionMap);
	
	/**
	 * Clone the current datasource, using the same response of the server from the original one
	 * and the same fields expressions map but a different base path
	 * 
	 * @param basePath the new base path, must be not null and not empty
	 * @return a not null datasource, should be a clone of the data source where the method is called
	 * and it should be not consumed.
	 */
	public IWSDataSource clone(String basePath);
	
	/**
	 * Set the pattern to format the number to convert the textual representation
	 * into a real number
	 * 
	 * @param pattern the pattern
	 */
	public void setNumberPattern(String pattern);
	
	/**
	 * Set the pattern to format the date to convert the textual representation
	 * into a java.util.Date
	 * 
	 * @param pattern the pattern
	 */
	public void setDatePattern(String pattern);
}
