/*******************************************************************************
 * Copyright (C) 2005 - 2014 TIBCO Software Inc. All rights reserved.
 * http://www.jaspersoft.com.
 * 
 * Unless you have purchased  a commercial license agreement from Jaspersoft,
 * the following license terms  apply:
 * 
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 ******************************************************************************/
package com.jaspersoft.webservice.data.query;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.jaspersoft.webservice.data.query.definition.WebServiceQuery;

/**
 * Parser used to convert the query from and to string. As string it is encoded
 * into a json format
 * 
 * @author Orlandin Marco
 *
 */
public class WebServiceParser {
	
	/**
	 * The json converter
	 */
	private static final ObjectMapper mapper = new ObjectMapper();
	
	/**
	 * the logger
	 */
	private static final Log logger = LogFactory.getLog(WebServiceParser.class);
	
	/**
	 * Convert a textual query into a WebServiceQuery. If something goes
	 * wrong (invalid query) it return a base query
	 * 
	 * @param query json text of the query
	 * @return a not null WebServiceQuery
	 */
	public static WebServiceQuery parseQuery(String query){
		//check if the query is null or empty and in case retrun the default one
		if (query == null || query.trim().isEmpty()) {
			return new WebServiceQuery();
		} else {
			try {
				return mapper.readValue(query, WebServiceQuery.class);
			} catch (Exception e) {
				e.printStackTrace();
				logger.error(query, e);
				return new WebServiceQuery();
			} 
		}
	}
	
	/**
	 * Convert a WebServiceQuery into its json textual representation
	 * 
	 * @param query a not null query
	 * @return a not null text, if something goes wrong during the conversion it
	 * return the empty string
	 */
	public static String generateQuery(WebServiceQuery query){
		try {
			
			return mapper.writerWithDefaultPrettyPrinter().writeValueAsString(query);
		} catch (JsonProcessingException e) {
			e.printStackTrace();
			logger.error(query, e);
			return "";
		}
	}
}
