/*******************************************************************************
 * Copyright (C) 2005 - 2014 TIBCO Software Inc. All rights reserved.
 * http://www.jaspersoft.com.
 * 
 * Unless you have purchased  a commercial license agreement from Jaspersoft,
 * the following license terms  apply:
 * 
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 ******************************************************************************/

package com.jaspersoft.webservice.data.query;

import java.util.Map;

import com.jaspersoft.webservice.data.WebServiceDataAdapterService;

import net.sf.jasperreports.engine.DefaultJasperReportsContext;
import net.sf.jasperreports.engine.JRDataset;
import net.sf.jasperreports.engine.JRException;
import net.sf.jasperreports.engine.JRValueParameter;
import net.sf.jasperreports.engine.JasperReportsContext;
import net.sf.jasperreports.engine.query.JRQueryExecuter;
import net.sf.jasperreports.engine.query.QueryExecuterFactory;

/**
 * Query executer factory for WebQL queries.
 * This factory creates {@link WebServiceQueryExecuter} for WebQL queries.
 *
 * @author Orlandin Marco
 *
 */
public class WebServiceQueryExecuterFactory implements QueryExecuterFactory {
	
	/**
	 * Parameter name of the parameter that will contains the pattern to format dates
	 */
	public static final String DATE_PATTERN_NAME = "REPORT_DATE_FIELDS_PATTERN";
	
	/**
	 * Parameter name of the parameter that will contains the pattern to format numbers
	 */
	public static final String NUMBER_PATTERN_NAME = "REPORT_NUMBER_FIELDS_PATTERN";

    /**
     * Creates a {@link WebServiceQueryExecuter}.<br/>
     * <br/>
     * This method is called at fill time for reports/datasets having a query
     * supported by this factory (WebQL query).
     */
    public JRQueryExecuter createQueryExecuter(JasperReportsContext jasperReportsContext, JRDataset dataset, Map<String, ? extends JRValueParameter> parameters) throws JRException {
        return new WebServiceQueryExecuter(jasperReportsContext, dataset, parameters);
    }

    /**
     * Return the parameters required by the WebService query executer. The even position
     * are the parameter name, the odd are the parameter type, as strig (ie java.lang.Object)
     * 
     * @return a not null array of string
     */
    public Object[] getBuiltinParameters() {
    	Object[] builtInParameters = new Object[10];
    	builtInParameters[0] = WebServiceDataAdapterService.URI_KEY;
    	builtInParameters[1] = String.class.getName();
    	builtInParameters[2] = WebServiceDataAdapterService.AUTH_TYPE_KEY;
    	builtInParameters[3] = String.class.getName();
    	builtInParameters[4] = WebServiceDataAdapterService.AUTH_PARAMETERS_KEY;
    	builtInParameters[5] = Object.class.getName();
    	builtInParameters[6] = WebServiceDataAdapterService.LANGUAGE_KEY;
    	builtInParameters[7] = Object.class.getName();
    	builtInParameters[8] = WebServiceDataAdapterService.VERB_KEY;
    	builtInParameters[9] = Object.class.getName();
        return builtInParameters;
    }

    public boolean supportsQueryParameterType(String queryParameterType) {
        return true;
    }

    @Override
    public WebServiceQueryExecuter createQueryExecuter(JRDataset dataset, Map<String, ? extends JRValueParameter> parameters)  throws JRException {
        return new WebServiceQueryExecuter(DefaultJasperReportsContext.getInstance(), dataset, parameters);
    }
}