/*******************************************************************************
 * Copyright (C) 2005 - 2014 TIBCO Software Inc. All rights reserved.
 * http://www.jaspersoft.com.
 * 
 * Unless you have purchased  a commercial license agreement from Jaspersoft,
 * the following license terms  apply:
 * 
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 ******************************************************************************/
package com.jaspersoft.webservice.data.query.definition;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;

/**
 * Object that represent a query for the WebService data adapter. It 
 * uses annotations to be serializable into a JSON object. It has
 * no logic in it, it is only a data container
 * 
 * @author Orlandin Marco
 *
 */
public class WebServiceQuery {
	
	@JsonProperty("fields")
	private List<Field> fields = new ArrayList<Field>();
	
	@JsonProperty("options")
	private Options options = new Options();
	
	@JsonProperty("headersMap")
	private Map<String, String> headersMap = new HashMap<String, String>();

	@JsonProperty("queryData")
	private String queryData = "";
	
	@JsonProperty("GETParameters")
	private Map<String, String> GETParameters = new HashMap<String, String>();;

	//GETTERS AND SETTERS
	
	public List<Field> getFields() {
		return fields;
	}

	public void setFields(List<Field> fields) {
		this.fields = fields;
	}

	public Options getOptions() {
		return options;
	}

	public void setOptions(Options options) {
		this.options = options;
	}

	public String getQueryData() {
		return queryData;
	}

	public void setQueryData(String queryData) {
		this.queryData = queryData;
	}
	
	public Map<String, String> getHeadersMap() {
		return headersMap;
	}

	public void setHeadersMap(Map<String, String> headersMap) {
		this.headersMap = headersMap;
	}
	
	public void addField(Field field){
		fields.add(field);
	}
	
	public void addHeader(String name, String value){
		headersMap.put(name, value);
	}
	
	public Map<String,String> getGETParameters(){
		return GETParameters;
	}
	
	public void setGETParameters(Map<String, String> GETParameters){
		this.GETParameters = GETParameters;
	}
	
	@JsonIgnore
	public Map<String,String> getFieldsMap(){
		Map<String, String> result = new LinkedHashMap<String, String>();
		for(Field field : fields){
			result.put(field.getName(), field.getExpression());
		}
		return result;
	}
}
