/*******************************************************************************
 * Copyright (C) 2005 - 2014 TIBCO Software Inc. All rights reserved.
 * http://www.jaspersoft.com.
 * 
 * Unless you have purchased  a commercial license agreement from Jaspersoft,
 * the following license terms  apply:
 * 
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 ******************************************************************************/
package com.jaspersoft.webservice.data.query.exception;

import java.io.UnsupportedEncodingException;

import com.jaspersoft.webservice.data.enumerations.LanguageType;
import com.jaspersoft.webservice.data.util.WsResponse;

import net.sf.jasperreports.engine.JRException;

/**
 * Exception triggered when there is a response parsing error. Essentially the server
 * return something but this can not be parsed by the current language handler
 */
public class JRParseException extends JRException {

	private static final long serialVersionUID = 6472641845617513226L;

	private LanguageType language;
	
	private String messageToParse = null; 
	
	private WsResponse serverResponse;
	
	public JRParseException(Throwable t, LanguageType language, WsResponse serverResponse) {
		super(t);
		this.language = language;
		if (serverResponse != null){
			this.serverResponse = serverResponse;
			try {
				this.messageToParse = new String(serverResponse.getResultStream(), "UTF-8");
			} catch (UnsupportedEncodingException e) {
				e.printStackTrace();
			}
		}
	}

	@Override
	public String toString() {
		StringBuilder message = new StringBuilder("Error while parsing the response from the server with language ");
		message.append(language.toString());
		if (messageToParse != null){
			message.append("\nThe server has retruned the following response: \n");
			message.append(messageToParse);
		}
		if (serverResponse != null){
			message.append("\nResponse Code: ");
			message.append(serverResponse.getReturnCode());
			message.append("\nServer request information \n");
			message.append(serverResponse.getRequestInfo());
		}
		message.append("\nAdditional informations: \n");
		message.append(getCause().toString());
		return message.toString();
	}
	
}
