/*******************************************************************************
 * Copyright (C) 2005 - 2014 TIBCO Software Inc. All rights reserved.
 * http://www.jaspersoft.com.
 * 
 * Unless you have purchased  a commercial license agreement from Jaspersoft,
 * the following license terms  apply:
 * 
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 ******************************************************************************/
package com.jaspersoft.webservice.data.util;

import java.util.Map;

import com.jaspersoft.webservice.data.enumerations.AuthType;
import com.jaspersoft.webservice.data.enumerations.VerbType;

import net.sf.jasperreports.engine.JRException;

/**
 * Interface that define how a connector for a specific verb type must be done.
 * The connector is the class that handle all the communication with the server
 * 
 * @author Orlandin Marco
 */
public interface WebServiceConnectorInterface {

	/**
	 * Create the request, send it to the server and return the response
	 *
	 * @param wsURI The uri of the web service
	 * @param baseURL the base url for the resource
	 * @param verbType The verb of the request
	 * @param authType The authorization type for the request
	 * @param contentType  The content type of the request (used only with a post verb)
	 * @param content The content of the request (used only with a post verb)
	 * @param authMap The map of the parameters used for the authentication
	 * @param headerMap The map of headers to insert into the request
	 * @param GETParameters The map of the parameters used for a get request (used only with a GET verb)
	 * @return the response from the server
	 * @throws JRException raised if something goes wrong with the server
	 */
	public WsResponse callWS(String wsURI, String baseURL, VerbType verbType, 
			  AuthType authType, String contentType, String content,
			  Map<String, String> authMap, Map<String, String> headerMap, 
			  Map<String,String> GETParameters)  throws JRException;
	
}
