/*******************************************************************************
 * Copyright (C) 2005 - 2014 TIBCO Software Inc. All rights reserved.
 * http://www.jaspersoft.com.
 * 
 * Unless you have purchased  a commercial license agreement from Jaspersoft,
 * the following license terms  apply:
 * 
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 ******************************************************************************/
package com.jaspersoft.studio.data.webservice.google.authenticator;

import java.util.HashMap;

import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;

import com.jaspersoft.weservice.authenticator.google.GoogleAuthenticator;

/**
 * Wizard page provided by the basic configurator type, it offers
 * the control to provide username and password
 * 
 * @author Orlandin Marco
 *
 */
public class GoogleAuthWizardPage extends WizardPage {

	/**
	 * Field for the username
	 */
	private Text key;
	
	/**
	 * Map where the value of the parameters is stored
	 */
	private HashMap<String, String> parameters;
	
	/**
	 * When one of the input control is modified it update the corresponding value on the map
	 */
	private ModifyListener valueModified = new ModifyListener() {
		
		@Override
		public void modifyText(ModifyEvent e) {
			parameters.put(GoogleAuthenticator.KEY_PARAM_NAME, key.getText());
		}
	};
	
	/**
	 * Create the wizard page to provide username and password
	 * 
	 * @param parameters the parameters provided
	 */
	public GoogleAuthWizardPage(HashMap<String, String> parameters) {
		super("parameterPage"); //$NON-NLS-1$
		this.parameters = parameters;
		setTitle("Google key configuration");
		setDescription("Provide your google key");
	}

	@Override
	public void createControl(Composite parent) {
		Composite container = new Composite(parent, SWT.NONE);
		container.setLayout(new GridLayout(2,false));
		container.setLayoutData(new GridData(GridData.FILL_BOTH));
		
		new Label(container, SWT.NONE).setText("Google Key");
		key = new Text(container, SWT.BORDER);
		key.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		String keyValue = parameters.get(GoogleAuthenticator.KEY_PARAM_NAME);
		if (keyValue != null) key.setText(keyValue);
		key.addModifyListener(valueModified);

		
		setControl(container);
	}
}
