/*******************************************************************************
 * Copyright (C) 2005 - 2014 TIBCO Software Inc. All rights reserved.
 * http://www.jaspersoft.com.
 * 
 * Unless you have purchased  a commercial license agreement from Jaspersoft,
 * the following license terms  apply:
 * 
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 ******************************************************************************/
package com.jaspersoft.studio.data.webservice.google.content;

import java.util.Map;

import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.StyledText;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import com.jaspersoft.studio.data.designer.UndoRedoImpl;
import com.jaspersoft.studio.data.webservice.designer.DropProvider;
import com.jaspersoft.studio.data.webservice.designer.contenttype.ContentTypeDefinition;
import com.jaspersoft.webservice.data.query.definition.WebServiceQuery;

/**
 * Content type provider for a google maps request where the users 
 * can specify an origin and a destination for the path. It supports
 * the drag and drop and the undo redu
 * 
 * @author Orlandin Marco
 *
 */
public class GoogleMapsParameterContentType implements ContentTypeDefinition {
	
	private StyledText origin;
	
	private StyledText destination;
	
	public static final String ORIGIN_KEY = "origin";
	
	public static final String DESTINATION_KEY = "destination";
	
	@Override
	public String getUIName() {
		return "Google Maps";
	}

	@Override
	public String getContentType() {
		return "application/maps"; //$NON-NLS-1$
	}

	@Override
	public void createControl(Composite parent) {
		parent.setLayout(new GridLayout(2,false));
		new Label(parent, SWT.NONE).setText("Origin");
		origin = new StyledText(parent, SWT.SINGLE | SWT.BORDER);
		origin.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		
		new Label(parent, SWT.NONE).setText("Destination");
		destination = new StyledText(parent, SWT.SINGLE | SWT.BORDER);
		destination.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		
		//Add drop support
		DropProvider.setStyledTextDropTargetEffect(origin);
		DropProvider.setStyledTextDropTargetEffect(destination);
		
		//Add undo\redo support
		new UndoRedoImpl(origin);
		new UndoRedoImpl(destination);
	}
		
	@Override
	public void setRequestContent(WebServiceQuery query) {
		Map<String, String>  parameters = query.getGETParameters();
		
		String originValue = parameters.get(ORIGIN_KEY);
		if (origin != null && originValue != null) origin.setText(originValue);

		String destinationValue = parameters.get(DESTINATION_KEY);
		if (destination != null && destinationValue != null) destination.setText(destinationValue);
	}

	@Override
	public void addModifyListener(ModifyListener listener) {
		origin.addModifyListener(listener);
		destination.addModifyListener(listener);
	}

	@Override
	public void updateRequestContent(WebServiceQuery query) {
		Map<String, String> newParameters = query.getGETParameters();
		newParameters.put(ORIGIN_KEY, origin.getText());
		newParameters.put(DESTINATION_KEY, destination.getText());
		query.setGETParameters(newParameters);
	}

}
